<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Piilotetut pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Nämä kovakoodatut pikanäppäimet ohitetaan, jos ne on määritetty myös muille toiminnoille kohdassa Asetukset → Pikanäppäimet.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Toiminto</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Sulje ikkuna tai poistu koko näytön tilasta</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Seuraava kuva</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Välilyönti</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Viimeinen kuva</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Edellinen kuva</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Askelpalautin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Ensimmäinen kuva</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="93"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Käynnistä koko näytön tilassa (hyödyllinen laattanäkymiä hyödyntävissä ikkunanhallintamalleissa)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Ota kuvakaappaus (vanhentunut toiminto, käytäthän käyttöjärjestelmän omaa kaappausta)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>DIR</source>
        <translation>HAK</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Ota kuvakaappaus ja tallenna se hakemistoon näyttämättä graafista käyttöliittymää (vanhentunut, käytäthän käyttöjärjestelmän omaa kaappainta)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="116"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[TIEDOSTO1, TIEDOSTO2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>tuntematon virhevastine</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>tuntematon virhevastine</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Yksinkertainen ja nopea kuvankatseluohjelma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Tekijänoikeus (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>LXQt-hanke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Kehitystyö: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Päätekijä: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Avaa tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Kuvatiedostot (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Avaa hakemisto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Tallenna tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Lataa...) - Kuvankatselin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (lataus epäonnistui) - Kuvankatselin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Kuvankatselin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Kuvankatselin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Pienoiskuvat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>EXIF-tietueet</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Tyhjennä</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Käytä muokkainnappia pyyhkiäksesi
oikopolun muokkaustilassa.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>Alhaalla</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>Ylhäällä</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Vasemmalla</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Varoitus: Epäselvä pikanäppäin havaittu!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Epäselvä pikanäppäin hylätty.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Tätä kuvatiedostomuodoa ei tueta!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Polku:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Kuvankatselin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Hiljattain avatut tiedostot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Annotations Toolbar</source>
        <translation>Huomautusten työkalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Avaa &amp;sovelluksessa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Lajittele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>&amp;Piilotetut pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Avaa…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Lataa tiedosto uudelleen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Tallenna &amp;nimellä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Lähen&amp;nä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>Loit&amp;onna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Tallenna leikepöydälle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Seuraava tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Edellinen tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Alkuperäinen koko</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>&amp;Sovita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Kierrä myötäpäivään</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Kierrä &amp;vastapäivään</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>A&amp;setukset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>&amp;Print</source>
        <translation>&amp;Tulosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>First File</source>
        <translation>Ensimmäinen tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Last File</source>
        <translation>Viimeinen tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>&amp;New Window</source>
        <translation>&amp;Uusi ikkuna</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Käännä &amp;vaakatasossa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>Capture Screenshot</source>
        <translation>Ota kuvakaappaus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>F&amp;ull Screen</source>
        <translation>K&amp;oko näyttö</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Flip &amp;Vertically</source>
        <translation>Käännä &amp;pystysuunnassa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Liitä leikepöydältä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaesitys</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Show Thumbnails</source>
        <translation>Näytä pienoiskuvat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>File Properties</source>
        <translation>Tiedoston ominaisuudet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="562"/>
        <source>Open &amp;Directory</source>
        <translation>A&amp;vaa hakemisto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>Upload</source>
        <translation>Lähetä verkkopalveluun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Upload the image</source>
        <translation>Lähetä kuva verkkopalveluun</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Show EXIF Data</source>
        <translation>Näytä EXIF-tietueet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>No Tool</source>
        <translation>Ei työkalua</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Deselect all drawing tools</source>
        <translation>Epävalitse kaikki piirtotyökalut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="615"/>
        <source>Draw Arrow</source>
        <translation>Piirrä nuoli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Draw an arrow</source>
        <translation>Piirrä nuoli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="630"/>
        <source>Draw Rectangle</source>
        <translation>Piirrä suorakulmio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="633"/>
        <source>Draw a hollow rectangle</source>
        <translation>Piirrä ontto suorakulmio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Draw Circle</source>
        <translation>Piirrä ympyrä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>Draw a hollow circle</source>
        <translation>Piirrä ontto ympyrä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Draw Number</source>
        <translation>Piirrä numero</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Draw incrementing numbers</source>
        <translation>Piirrä kasvavia numeroita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Menubar</source>
        <translation>Valikkorivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Päätyökalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="688"/>
        <source>Main Toolbar</source>
        <translation>Päätyökalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Huomautusten työkalurivi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <location filename="../mainwindow.ui" line="710"/>
        <source>Show Outline</source>
        <translation>Näytä ääriviivat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="721"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopioi &amp;polku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Copy path</source>
        <translation>Kopioi polku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Rename</source>
        <translation>Uudelleennimeä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Resize</source>
        <translation>Muokkaa kokoa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>&amp;By File Name</source>
        <translation>Tiedosto&amp;nimen mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>By File Name</source>
        <translation>Tiedostonimen mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="766"/>
        <source>By &amp;Modification Time</source>
        <translation>&amp;Muokkausajan mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>By Modification Time</source>
        <translation>Muokkausajan mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="777"/>
        <source>By C&amp;reation Time</source>
        <translation>&amp;Luomisajan mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>By Creation Time</source>
        <translation>Luomisajan mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="788"/>
        <source>By File &amp;Size</source>
        <translation>&amp;Tiedostokoon mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>By File Size</source>
        <translation>Tiedostokoon mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="799"/>
        <source>By File &amp;Type</source>
        <translation>Tiedosto&amp;tyypin mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="802"/>
        <source>By File Type</source>
        <translation>Tiedostotyypin mukaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Työkalurivi</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Kuvaketeema:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Pienoiskuvatiedoston kokoraja:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Perustaustaväri:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Kokonäytön taustaväri:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Maksimimäärä viimeisiä tiedostoja:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Diaesityksen viive (sekunteja):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Näytä kuvan ääriviivat oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Näytä huomautusten työkalurivi oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Sovita kuvat selatessa</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Pienoiskuvan mitat:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Käytä järjestelmän roskakoria (kysymättä)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Ikkuna</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Näytä pienoiskuvapalkki oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Näytä EXIF-tietuepalkki oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Näytä valikkopalkki oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Näytä päätyökalurivi oletuksena</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Kuvan täytyy käyttää kelvollista väriavaruutta, että se voidaan näyttää.
Lataa kuva uudelleen nähdäksesi vaikutuksen.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Väriavaruus:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (useimmat näytöt tukevat)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>Lineaarinen sRGB (lineaarinen gamma)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (laajatoistoalanäytöt)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Pehmennä kuva zoomatessa</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Toiminto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>Oletukset</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Yleisasetukset</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="996"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Muuta kuvan kokoa</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Nykyinen koko:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Uusi koko:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Pidä kuvasuhde</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Kuvakaappaus</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Ota kuvakaappaus</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Alue</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Nykyinen ikkuna</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Kaappaa alue näytöltä</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Sisällytä hiiren kursori</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Viive:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Sisällytä ikkunan otsikko ja kehys</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Lähetä verkkopalveluun</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
</context>
</TS>
